==> sdd.praapi-0.1.11-sources.jar: ar/com/sdd/praapi/io/CommonError.java <==
package ar.com.sdd.praapi.io;

import ar.com.sdd.praapi.model.ErrorRecord;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class CommonError implements Serializable {

    @JsonProperty("errorRecords")
    private List<ErrorRecord> errorRecords;

    @JsonProperty("timestamp")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX", timezone = "GMT-03:00")
    private Date timestamp;

    public List<ErrorRecord> getErrorRecords() {
        return errorRecords;
    }

    public void setErrorRecords(List<ErrorRecord> errorRecords) {
        this.errorRecords = errorRecords;
    }

    public Date getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Date timestamp) {
        this.timestamp = timestamp;
    }

    @Override
    public String toString() {
        return "CommonError [" +
                ((errorRecords != null) ? "errorRecords=" + Arrays.toString(errorRecords.toArray()) + ", " : "") +
                ((timestamp != null) ? "timestamp=" + timestamp + ", " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CommonError that = (CommonError) o;
        return Objects.equals(errorRecords, that.errorRecords) && Objects.equals(timestamp, that.timestamp);
    }

    @Override
    public int hashCode() {
        return Objects.hash(errorRecords, timestamp);
    }
}

==> sdd.praapi-0.1.18-sources.jar: ar/com/sdd/praapi/io/CommonError.java <==
package ar.com.sdd.praapi.io;

import ar.com.sdd.praapi.model.Error;
import ar.com.sdd.praapi.model.ErrorRecord;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class CommonError implements Serializable {

    @JsonProperty("errorRecords")
    private List<ErrorRecord> errorRecords;

    @JsonProperty("timestamp")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX", timezone = "GMT-03:00")
    private Date timestamp;

    @JsonProperty("error")
    private Error error;

    public List<ErrorRecord> getErrorRecords() {
        return errorRecords;
    }

    public void setErrorRecords(List<ErrorRecord> errorRecords) {
        this.errorRecords = errorRecords;
    }

    public Date getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Date timestamp) {
        this.timestamp = timestamp;
    }

    public Error getError() {
        return error;
    }

    public void setError(Error error) {
        this.error = error;
    }

    @Override
    public String toString() {
        return "CommonError [" +
                ((errorRecords != null) ? "errorRecords=" + Arrays.toString(errorRecords.toArray()) + ", " : "") +
                ((timestamp != null) ? "timestamp=" + timestamp + ", " : "") +
                ((error != null) ? "error=" + error + ", " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CommonError that = (CommonError) o;
        return Objects.equals(errorRecords, that.errorRecords) && Objects.equals(timestamp, that.timestamp) && Objects.equals(error, that.error);
    }

    @Override
    public int hashCode() {
        return Objects.hash(errorRecords, timestamp, error);
    }
}
